import type { ReactElement, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { PaperProps } from "../Paper";
export interface AccordionProps extends Omit<PaperProps, "square" | "elevation" | "onChange"> {
    /**
     * The content of the accordion.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The header content of the accordion.
     */
    header: ReactNode;
    /**
     * If the `header` is a string the level of the header.
     * @default "h2"
     */
    headerLevel?: "h1" | "h2" | "h3" | "h4" | "h5" | "h6";
    /**
     * Extra items in the accordion header
     * @default undefined
     */
    headerItems?: ReactNode;
    /**
     * If `true` the initial state of the accordion will be expanded.
     * @default false
     */
    defaultExpanded?: boolean;
    /**
     * If `true` the accordion will be expanded, used for controlled state.
     * @default false
     */
    expanded?: boolean;
    /**
     * The position of the chevron icon.
     * @default "left"
     */
    expandIconPosition?: "left" | "right";
    /**
     * The icon to display as the expand indicator.
     * @default undefined
     */
    expandIcon?: ReactElement;
    /**
     * If `true`, the accordion will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, shows a box-shadow.
     * @default false
     */
    elevation?: boolean;
    /**
     * If `true`, rounded corners are disabled.
     * @default true
     */
    square?: boolean;
    /**
     * Callback fired when the expand/collapse state is changed.
     * @default undefined
     */
    onChange?: (expanded: boolean, event: SyntheticEvent) => void;
}
