import type { HTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface AlertProps extends Omit<HTMLAttributes<HTMLDivElement>, "title">, SpaceProps, TypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The message description of the alert.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The variant to use.
     * @default "contained"
     */
    variant?: "contained" | "outlined" | "ghost";
    /**
     * The severity of the alert. This defines the color and icon used.
     *  @default "info"
     */
    severity?: "info" | "success" | "warning" | "error";
    /**
     * The title of the alert.
     */
    title: string | ReactNode;
    /**
     * `true` to show an alert icon base on EDS icons, otherwise `false`.
     * @default false
     */
    showIcon?: boolean;
    /**
     * Override the icon displayed if the `showIcon` is set to `true`.
     * @default undefined
     */
    icon?: ReactNode;
    /**
     * Callback fired when the component requests to be closed.
     *
     * When defined this function a close icon button is displayed that triggers the callback when clicked.
     *
     * @default undefined
     */
    onClose?: (event: SyntheticEvent) => void;
}
