import type { TopbarProps as EdsTopbarProps } from "@equinor/eds-core-react";
import type { ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, ColorProps, PositionProps, ShadowProps, SpaceProps } from "styled-system";
export interface AppBarProps extends Omit<EdsTopbarProps, "color" | "content">, SpaceProps, ColorProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The header block.
     * @default undefined;
     */
    header?: ReactNode;
    /**
     * The content block.
     * @default undefined
     */
    content?: ReactNode;
    /**
     * The content to render on small screen sizes. If non is provided will use `content`.
     * @default undefined
     */
    smallScreenContent?: ReactNode;
    /**
     * Controlled state for the menu when the app bar is smaller than `smallScreenSize`.
     * @default undefined
     */
    smallScreenContentOpen?: boolean;
    /**
     * Callback fired when the menu request to be open.
     * @default undefined
     */
    smallScreenContentOnOpen?: (event: SyntheticEvent | Event) => void;
    /**
     * Callback fired when the menu request to be closed.
     * @default undefined
     */
    smallScreenContentOnClose?: (event: SyntheticEvent | Event) => void;
    /**
     * The actions block.
     * @default undefined
     */
    actions?: ReactNode;
    /**
     * The actions to render on small screen sizes. If non is provided will use `actions`.
     * @default undefined
     */
    smallScreenActions?: ReactNode;
    /**
     * The width from which a screen is considered to be small and the app bar will render his compact version.
     * @default 425
     */
    smallScreenSize?: number;
}
