import type { HtmlHTMLAttributes, ImgHTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, ColorProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface AvatarProps extends Omit<HtmlHTMLAttributes<HTMLDivElement>, "color">, SpaceProps, ColorProps, TypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * Used to render icon or text elements inside the Avatar if `src` is not set.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The shape of the avatar.
     * @default "circle"
     */
    variant?: "circle" | "rounded" | "square";
    /**
     * alt attribute for the rendered img element.
     * @default undefined
     */
    alt?: string;
    /**
     * The `src` attribute for the `img` element.
     * @default undefined
     */
    src?: string;
    /**
     * The `srcSet` attribute for the `img` element. Use this attribute for responsive image display.
     * @default undefined
     */
    srcSet?: string;
    /**
     * The size of the avatar.
     * @default 24
     */
    size?: number;
    /**
     *  If `true`, the avatar will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Attributes applied to the `img` element if the component is used to display an image.
     *
     * It can be used to listen for the loading error event.
     *
     * @default {}
     */
    imgProps?: ImgHTMLAttributes<HTMLImageElement>;
}
