import type { ReactNode } from "react";
import type { TransitionProps } from "react-transition-group/Transition";
import type { ButtonProps } from "../Button";
export interface BackToTopProps extends Omit<ButtonProps, "href" | "target" | "rel"> {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The target to scroll to top. By default will be the owner document where the element is placed.
     * @default undefined
     */
    target?: HTMLElement | string;
    /**
     * Side from which the BackToTop button will appear.
     * @default "bottom-right"
     */
    placement?: "left-top" | "right-top" | "bottom-left" | "bottom-right";
    /**
     * The value that the scroll should reach in order to show the component.
     * @default 400
     */
    thresholdHeight?: number;
    /**
     * The duration for the transition, in milliseconds. You may specify a single timeout for all transitions, or individually with an object.
     * @default undefined
     */
    transitionDuration?: number | {
        appear: number;
        enter: number;
        exit: number;
    };
    /**
     * Properties object for the transition component.
     * @default {}
     */
    transitionProps?: TransitionProps;
}
