import type { HtmlHTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { TransitionProps } from "react-transition-group/Transition";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, ColorProps, LayoutProps, PositionProps } from "styled-system";
export interface BackdropProps extends Omit<HtmlHTMLAttributes<HTMLDivElement>, "color">, ColorProps, LayoutProps, BackgroundProps, PositionProps {
    /**
     * The element to show in top of the backdrop.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * If `true`, the backdrop is open.
     */
    open: boolean;
    /**
     * If true, the backdrop is invisible.
     * @default false
     */
    invisible?: boolean;
    /**
     * Whether the backdrop can be closed with esc key and outside click.
     * @default false
     */
    closable?: boolean;
    /**
     * Always keep the children in the DOM.
     * @default false
     */
    keepMounted?: boolean;
    /**
     * The duration for the transition, in milliseconds.
     *
     * You may specify a single timeout for all transitions, or individually with an object.
     *
     * @default undefined
     */
    transitionDuration?: number | {
        appear: number;
        enter: number;
        exit: number;
    };
    /**
     * Properties object for the transition component.
     * @default {}
     */
    transitionProps?: TransitionProps;
    /**
     * Callback fired when the backdrop is closable and click on the backdrop or the esc key.
     * @default undefined
     */
    onClose?: (event: SyntheticEvent | Event) => void;
}
