import type { HTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, ColorProps, LayoutProps, PositionProps, ShadowProps, TypographyProps } from "styled-system";
export interface BadgeProps extends Omit<HTMLAttributes<HTMLDivElement>, "color" | "content">, ColorProps, TypographyProps, LayoutProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The component that will have the badge.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The variant to use, when using a dot the content will not be used,
     * the badge it's only a dot with a background color.
     * @default "default"
     */
    variant?: "default" | "dot";
    /**
     * The alignment tof the badge.
     * @default "top-right"
     */
    alignment?: "top-left" | "top-right" | "bottom-left" | "bottom-right";
    /**
     * The content of the badge, used if the variant is `default`.
     * @default undefined
     */
    content?: number | ReactNode;
    /**
     * If `false` the badge will be invisible.
     * @default true
     */
    visible?: boolean;
    /**
     * If the content is a number, the max number to show. If a content pass this max number the badge
     * will show `${max}+`.
     * @default 99
     */
    max?: number;
    /**
     * Wrapped shape the badge should overlap. If use a circle the badge will be moved a 14% to the center
     * relative to the alignment position.
     * @default "rectangle"
     */
    overlap?: "circle" | "rectangle";
}
