import type { BaseHTMLAttributes, ForwardRefExoticComponent, ReactNode, RefAttributes } from "react";
import type { CSSObject } from "styled-components";
import type { ColorProps, HeightProps, SpaceProps, WidthProps } from "styled-system";
export interface BaseIconProps extends BaseHTMLAttributes<HTMLSpanElement>, SpaceProps, Omit<ColorProps, "color">, WidthProps, HeightProps {
    /**
     * The icon an svg or a component.
     */
    children: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The color to be used, it can be an hexadecimal or a css color, it can also be one of the next types:
     * <br/>- default
     * <br/>- primary
     * <br/>- secondary
     * <br/>- success
     * <br/>- warning
     * <br/>- danger
     *
     * @default "inherit"
     */
    color?: string;
    /**
     * The size of the icon.
     * @default 24
     */
    size?: number;
    /**
     * Rotation of the icon.
     * @default 0
     */
    rotation?: number;
}
export interface BaseIconComponent extends ForwardRefExoticComponent<Omit<BaseIconProps, "children"> & RefAttributes<HTMLSpanElement>> {
}
