import type { ElementType, HTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { FlexboxProps, LayoutProps, PositionProps, SpaceProps, TypographyProps } from "styled-system";
type BreadcrumbsClickProps = {
    index: number;
};
export interface BreadcrumbsProps extends Omit<HTMLAttributes<HTMLDivElement>, "onClick">, SpaceProps, TypographyProps, LayoutProps, FlexboxProps, PositionProps {
    /**
     * The breadcrumbs.
     */
    children: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * Force the breadcrumb to be collapsed by default.
     * @default false
     */
    defaultCollapsed?: boolean;
    /**
     * The component used for the root node.
     * @default "nav"
     */
    as?: ElementType;
    /**
     * Specifies the maximum number of breadcrumbs to display.
     * When there are more than the maximum number, only the first and last items will be shown.
     * @default 8
     */
    maxItems?: number;
    /**
     * Custom separator node.
     * @default "/"
     */
    separator?: ReactNode;
    /**
     * The active breadcrumb.
     * @default undefined
     */
    activeIndex?: number;
    /**
     * Callback fired when click on a breadcrumb.
     *
     * `({ index }: BreadcrumbsClickProps, e: SyntheticEvent) => void`
     *
     * @default undefined
     */
    onClick?: (obj: BreadcrumbsClickProps, e: SyntheticEvent) => void;
}
export {};
