import type { ButtonHTMLAttributes, ElementType, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
interface ButtonBaseHTMLAttributes extends ButtonHTMLAttributes<HTMLButtonElement> {
    target?: string;
    rel?: string;
}
export interface ButtonProps extends ButtonBaseHTMLAttributes, SpaceProps, TypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     * @default "button"
     */
    as?: ElementType;
    /**
     * The color of the component.
     * @default "primary"
     */
    color?: "primary" | "secondary" | "danger";
    /**
     * The variant to use.
     * @default "contained"
     */
    variant?: "contained" | "outlined" | "ghost";
    /**
     * The URL to link to when the button is clicked. If defined, an `<a>` element will be used as the root node.
     * @default undefined
     */
    href?: string;
    /**
     * Element placed before the children.
     * @default undefined
     */
    startIcon?: ReactNode;
    /**
     * Element placed after the children.
     * @default undefined
     */
    endIcon?: ReactNode;
    /**
     * The size of the icon.
     * @default undefined
     */
    iconSize?: number;
    /**
     * If the button is in a loading state.
     * @default false
     */
    loading?: boolean;
    /**
     * `true` to show the button with a min height of 24px instead of 36px.
     * @default false
     */
    compact?: boolean;
    /**
     * If `true`, the button will take up the full width of its container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * If `true`, the button will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the ripple effect will be disabled.
     * @default false
     */
    disableRipple?: boolean;
}
export {};
