import type { HTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { LayoutProps, PositionProps, SpaceProps, TypographyProps } from "styled-system";
export type ButtonGroupClickProps = {
    index: number;
};
export interface ButtonGroupProps extends Omit<HTMLAttributes<HTMLDivElement>, "onChange">, SpaceProps, TypographyProps, LayoutProps, PositionProps {
    /**
     * The content of the component.
     */
    children: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The active button, from `0` to `n` number of buttons.
     * @default undefined
     */
    active?: number;
    /**
     * The default active button, from `0` to `n` number of buttons.
     * @default 0
     */
    defaultActive?: number;
    /**
     * The color of the component.
     * @default "primary"
     */
    color?: "primary" | "secondary" | "danger";
    /**
     * The variant to use.
     * @default "outlined"
     */
    variant?: "contained" | "outlined" | "ghost";
    /**
     * The variant to use on the active element.
     * @default "contained"
     */
    variantActive?: "contained" | "outlined" | "ghost";
    /**
     * The group orientation.
     * @default "horizontal"
     */
    orientation?: "vertical" | "horizontal";
    /**
     * `true` to show the button with a min height of 24px instead of 36px.
     * @default false
     */
    compact?: boolean;
    /**
     * If `true`, the button group will take up the full width of its container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * If `true`, the buttons will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Callback fired when change a selected button.
     *
     * `({ index }: ButtonGroupClickProps, e: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onChange?: (obj: ButtonGroupClickProps, e: SyntheticEvent) => void;
}
