import type { HTMLAttributes, ReactElement, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface ChipProps extends HTMLAttributes<HTMLDivElement>, SpaceProps, TypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The variant to use.
     * @default "default"
     */
    variant?: "default" | "selected" | "warning" | "error";
    /**
     * Component to place in the beginning of the component, it can be an icon.
     * @default undefined
     */
    startAdornment?: ReactElement;
    /**
     * Component to place in the end of the component, it can be an icon.
     * @default undefined
     */
    endAdornment?: ReactElement;
    /**
     * Whether the Chip can be closed.
     * @default false
     */
    closable?: boolean;
    /**
     * Whether the Chip is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the ripple effect will be disabled.
     * @default false
     */
    disableRipple?: boolean;
    /**
     * Callback fired when the chip is closed.
     * @default undefined
     */
    onClose?: (event: SyntheticEvent) => void;
    /**
     * Callback fired when the chip is clicked.
     * @default undefined
     */
    onClick?: (event: SyntheticEvent) => void;
}
