import type { HTMLAttributes } from "react";
import type { CSSObject } from "styled-components";
import type { ColorProps, FlexboxProps, PositionProps, ShadowProps, SpaceProps } from "styled-system";
export interface CircularProgressProps extends HTMLAttributes<HTMLSpanElement>, SpaceProps, Omit<ColorProps, "color">, FlexboxProps, PositionProps, ShadowProps {
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The variant to use. Use indeterminate when there is no progress value.
     * @default  "indeterminate"
     */
    variant?: "determinate" | "indeterminate";
    /**
     * The color of the loader.
     * @default undefined
     */
    color?: string;
    /**
     * The value of the progress indicator for the determinate variant. Value between 0 and 100.
     * @default 0
     */
    value?: number;
    /**
     * The size of the circle.
     * @default 48
     */
    size?: number;
    /**
     * The thickness of the circle.
     * @default 4
     */
    thickness?: number;
}
