import type { ReactNode, SyntheticEvent } from "react";
import type { TransitionProps } from "react-transition-group/Transition";
import type { BackdropProps } from "../Backdrop";
import type { PaperProps } from "../Paper";
import type { PortalProps } from "../Portal";
export interface DrawerProps extends PaperProps, Omit<PortalProps, "children"> {
    /**
     * If `true`, the drawer is open.
     * @default false
     */
    open?: boolean;
    /**
     * The variant to use.
     * <br/> - **permanent**: Always shown, it cannot be closed.
     * <br/> - **persistent**: A toggleable drawer.
     * <br/> - **temporary**: A toggleable drawer that opens as a portal with a backdrop layer.
     * <br/> - **responsive**: On a big screens it will act as a `persistent` and on small screens as a `temporary`.
     *
     * @default "temporary"
     */
    variant?: "permanent" | "persistent" | "temporary" | "responsive";
    /**
     * Side from which the drawer will appear.
     * @default "left"
     */
    placement?: "left" | "top" | "right" | "bottom";
    /**
     * The width from which a screen is considered to be small.
     * @default 425
     */
    smallScreenSize?: number;
    /**
     * A header title or component for the modal.
     * @default undefined
     */
    header?: ReactNode;
    /**
     * If `true` a close button will be shown in the header that allow to close the drawer.
     * @default false
     */
    closable?: boolean;
    /**
     * If `true` a full-screen button will be shown in the header of the drawer.
     * @default false
     */
    fullScreen?: boolean;
    /**
     * If the drawer should open full screen by default.
     * @default false
     */
    initialFullScreen?: boolean;
    /**
     * Always keep the children in the DOM.
     * @default false
     */
    keepMounted?: boolean;
    /**
     * The duration for the transition, in milliseconds. You may specify a single timeout for all transitions, or individually with an object.
     * @default undefined
     */
    transitionDuration?: number | {
        appear: number;
        enter: number;
        exit: number;
    };
    /**
     * Properties object for the transition component.
     * @default {}
     */
    transitionProps?: TransitionProps;
    /**
     * If `true`, the backdrop is not rendered.
     * @default false
     */
    hideBackdrop?: boolean;
    /**
     * Props applied to the `Backdrop` component.
     *
     * This component is only used when the `variant` is `temporary`.
     *
     * @default {}
     */
    backdropProps?: Omit<BackdropProps, "open" | "closable" | "keepMounted" | "transitionDuration" | "onClose">;
    /**
     * Callback fired when the component requests to be closed.
     * @default undefined
     */
    onClose?: (event: SyntheticEvent | Event) => void;
}
