/// <reference types="react" />
interface FilterInfo {
    /**
     * Name of the filter method to be executed.
     */
    filterKey: string;
    /**
     * If you have a source object with all the different data in that object,
     * the source key is the id of the data in that object.
     * If you are not using the concept of source, ignore this parameter.
     */
    sourceKey: string;
    /**
     * Options to pass to the filter function.
     */
    options?: object;
}
interface FilterDefinition {
    /**
     * The id of the filter.
     */
    id: string;
    /**
     * The label of the filter.
     * Can be a String or a Component.
     */
    label: string | JSX.Element;
    /**
     * Filter info object.
     */
    filterInfo: FilterInfo;
    /**
     * Array of child filters.
     */
    children?: Filter[];
}
export default class Filter {
    private readonly id;
    private readonly label;
    private readonly filterInfo;
    private readonly children?;
    /**
     * Filter constructor
     *
     * @param filterDefinition
     */
    constructor(filterDefinition: FilterDefinition);
    /**
     * @returns an `object` with the filter functions. The name of the
     * function will be the `filterKey`.
     */
    filters(): any;
    /**
     * Filter the data using one of the filters defined, if no filter find the
     * method will return the same data.
     *
     * @param data the data to filter.
     */
    filter(data: any[]): any[];
    /**
     * @returns a cloned instance of this object.
     */
    clone(): Filter;
    /**
     * @returns the filter id.
     */
    getId(): string;
    /**
     * @returns the filter label.
     */
    getLabel(): string | JSX.Element;
    /**
     * @returns the filter info object.
     */
    getFilterInfo(): FilterInfo;
    /**
     * @returns an array of child filters or undefined.
     */
    getChildren(): Filter[] | undefined;
}
export {};
