import { SelectedFilters, Sources } from "./entity";
import Filter from "./Filter";
export default class FilterBoss {
    private filteredResults;
    private filteredData;
    private readonly availableFilters;
    private readonly selectedFilters;
    /**
     * Constructor by default.
     *
     * @param filters Two-dimensional array of available filters.
     * Filters in same array are treated as by filtering OR and AND between arrays of filters.
     * @param defaultSelectedFilters Array of the selected filters.
     */
    constructor(filters: Filter[][], ...defaultSelectedFilters: Filter[]);
    /**
     * Add a filter to the selected filters.
     *
     * @param filter it can be the filter id or the filter itself.
     */
    addSelectedFilter(filter: string | Filter): void;
    /**
     * Remove a filter from the selected filters.
     *
     * @param filter it can be the filter id or the filter itself.
     */
    removeSelectedFilter(filter: string | Filter): void;
    /**
     * Toggle a filter:
     *  - if was selected will be removed.
     *  - if it was not selected will be added.
     *
     * @param filter it can be the filter id or the filter itself.
     */
    toggleSelectedFilter(filter: string | Filter): void;
    /**
     * Clear.
     */
    clear(): void;
    /**
     * Filter data sources object. If the data param is an array the filter will apply all the
     * input filters.
     *
     * Filters in same array are treated as by filtering OR and AND between arrays of filters.
     *
     * Algorithm complexity of O(log n + n)
     *
     * @param data - Map of sources that contains the data to be filtered or an array the data itself.
     * @param filters - Optional Two-dimensional array of available filters to override the initials.
     * @returns an object with the filtered sources and filtered results.
     */
    filter(data: Sources | any[], filters?: Filter[][]): object;
    /**
     *  @returns a Map with the filtered results as:
     *    - key: data
     * where key is the id of the filter and data an array with the filtered results.
     */
    getFilteredResults(): Map<string, any[]>;
    /**
     * @returns a Source Map or an array with the filtered results, it will depends on
     * how you filter the data. If you use a Source Map the filtered data will be a
     * Source Map, but if you use an array of data the filtered data will be an array
     * with the filtered results.
     */
    getFilteredData(): Sources | any[];
    /**
     * @returns a Map with the selected filters.
     */
    getSelectedFilters(): SelectedFilters;
}
