import type { SelectedFilters, Sources } from "../entity";
import Filter from "../Filter";
import TreeFilter from "../structure/TreeFilter";
/**
 * Generate a filtering tree structure, the tree structure is performed to
 * be used only with the filters to allow fast searching, and logarithmic
 * times to generate the results.
 *
 * This method has an algorithm complexity of O(log n)
 *
 * @param filters the multidimensional input filters.
 * @param selectedFilters the selected filters.
 * @returns flat array of logical filters.
 */
export declare const generateFilteringStructure: (filters: Filter[][], selectedFilters: SelectedFilters, sourceKey: string | undefined) => TreeFilter;
/**
 * Filter a data sources using a filtering tree data structure.
 *
 * This method has a algorithm complexity of O(log n)
 *
 * @param tree tree filter structure.
 * @param sources a Map with the source data.
 * @returns a copy of the sources map updated.
 */
export declare const filterSources: (tree: TreeFilter, sources: Sources) => Sources;
/**
 * Get the sources data results by filter, this method will also calculate the future
 * results for the unselected filters.
 *
 * This method has an algorithm complexity of O(n)
 *
 * @param tree tree filter structure.
 * @param filteredSources a Map with the filtered source data.
 * @param sources a Map with the source data.
 * @return a Map with the filters result data.
 */
export declare const filterResults: (tree: TreeFilter, filteredSources: Sources, sources: Sources) => Map<string, any[]>;
