import type { AnchorHTMLAttributes, ElementType, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, ColorProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface LinkProps extends Omit<AnchorHTMLAttributes<HTMLAnchorElement>, "color">, SpaceProps, Omit<ColorProps, "color">, TypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     */
    as?: ElementType;
    /**
     * The color to be used, it can be an hexadecimal or a css color, it can also be one of the next types:
     * <br/>- default
     * <br/>- primary
     * <br/>- secondary
     * <br/>- success
     * <br/>- warning
     * <br/>- danger
     * <br/>- disabled
     *
     * @default undefined
     */
    color?: "default" | "primary" | "secondary" | "success" | "warning" | "danger" | "disabled" | string;
    /**
     * Controls when the link should have an underline.
     */
    underline?: "none" | "always" | "hover";
}
