import type { ElementType, LiHTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { FlexboxProps, LayoutProps, SpaceProps, TypographyProps } from "styled-system";
export type MenuItemEvent = {
    id: string;
    label: ReactNode;
};
export interface MenuItemProps extends Omit<LiHTMLAttributes<HTMLLIElement>, "onClick">, SpaceProps, TypographyProps, LayoutProps, FlexboxProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     * @default "li"
     */
    as?: ElementType;
    /**
     * A unique id, if non is provided will generate a random one.
     * @default undefined
     */
    id?: string;
    /**
     * Component to place in the beginning of the component.
     * @default undefined
     */
    startAdornment?: ReactNode;
    /**
     * Component to place in the end of the component.
     * @default undefined
     */
    endAdornment?: ReactNode;
    /**
     * Whether menu item is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Whether the menu item doesn't have pointer events.
     * @default true
     */
    clickable?: boolean;
    /**
     * The outline offset css property.
     * @default undefined
     */
    outlineOffset?: string;
    /**
     * Callback fired when click on the menu item.
     *
     * `({ id, label }: MenuItemEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onClick?: (menuItemEvent: MenuItemEvent, event: SyntheticEvent) => void;
    /**
     * @ignore
     */
    isSubMenuItem?: boolean;
}
