import type { ReactNode, SyntheticEvent } from "react";
import type { MenuItemProps } from "../MenuItem";
import type { TooltipProps } from "../Tooltip";
export type SubMenuEvent = {
    id: string;
    label: ReactNode;
    level?: number;
};
export interface SubMenuProps extends Omit<MenuItemProps, "title" | "onClick"> {
    /**
     * The title of the menu element.
     */
    title: ReactNode;
    /**
     * Show/hide an arrow icon.
     * @default true
     */
    arrow?: boolean;
    /**
     * The submenu tooltip props. Only used when the submenu uses a tooltip.
     * @default {}
     */
    tooltipProps?: Omit<TooltipProps, "open" | "menu" | "contextMenu" | "arrow" | "overflowY" | "content">;
    /**
     * Callback fired when click on the sub-menu, only used when the mode is `inline`.
     *
     * `({ id, label, level }: SubMenuEvent, event: SyntheticEvent) => {}`
     *
     * @default undefined
     */
    onClick?: (subMenuEvent: SubMenuEvent, event: SyntheticEvent) => void;
}
