import type { ReactNode, SyntheticEvent } from "react";
import type { BackdropProps } from "../Backdrop";
import type { PaperProps } from "../Paper";
import type { PortalProps } from "../Portal";
export interface ModalProps extends Omit<PortalProps, "children">, Omit<PaperProps, "title"> {
    /**
     * If `true`, the modal is open.
     */
    open: boolean;
    /**
     * Show a close button in the modal.
     * @default true
     */
    showClose?: boolean;
    /**
     * Custom close icon.
     * @default <Clear />
     */
    closeIcon?: ReactNode;
    /**
     * The title of the modal.
     * @default undefined
     */
    title?: ReactNode;
    /**
     * If defined will show a footer on the modal.
     * This footer is designed to receive an array of buttons (actions) but you can add any component.
     * @default undefined
     */
    footer?: ReactNode;
    /**
     * Text of the OK button, it will only show the button if the `onOk` function is defined.
     * @default "Ok"
     */
    okText?: string;
    /**
     * Text of the Cancel button, it will only show the button if the `onCancel` function is defined.
     * @default "Cancel"
     */
    cancelText?: string;
    /**
     * If `true`, the modal will be full-screen.
     * @default false
     */
    fullScreen?: boolean;
    /**
     * Always keep the children in the DOM.
     * @default false
     */
    keepMounted?: boolean;
    /**
     * Backdrop props.
     * @default {}
     */
    backdropProps?: Omit<BackdropProps, "open" | "keepMounted" | "onClose">;
    /**
     * Callback fired when the component requests to be closed., the `backdropClosable` prop must be enabled.
     * @default undefined
     */
    onClose?: (event: SyntheticEvent | Event) => void;
    /**
     * Callback fired when click on the ok button. When defined this function the ok button will appear on the footer.
     * @default undefined
     */
    onOk?: (event: SyntheticEvent) => void;
    /**
     * Callback fired when click on the cancel button. When defined this function the cancel button appear on the footer.
     * @default undefined
     */
    onCancel?: (event: SyntheticEvent) => void;
}
