import type { ForwardRefExoticComponent, ReactNode, RefAttributes } from "react";
import type { PaperProps } from "../Paper";
import type { PortalProps } from "../Portal";
import type { ThemeProps } from "../ThemeProvider";
export type PLACEMENTS = "top-start" | "top" | "top-end" | "bottom-start" | "bottom" | "bottom-end";
export interface NotificationProps extends Omit<PortalProps, "children">, PaperProps {
    /**
     * If `true` the notification will be open.
     */
    open: boolean;
    /**
     * The message of the notification.
     * @default undefined
     */
    message?: ReactNode;
    /**
     * The actions to be shown on the right part of the notification.
     * @default undefined
     */
    actions?: ReactNode;
    /**
     * If `true` the notification will call the `onClose` function after `autoHideDuration` milliseconds.
     * @default true
     */
    autoHide?: boolean;
    /**
     * The number of milliseconds to wait before automatically calling the `onClose` function.
     * @default 6000
     */
    autoHideDuration?: number;
    /**
     * `true` to show a the time bar until call the `onClose` function.
     * This property only works if `autoHide` is enabled.
     * @default true
     */
    showAutoHideLoader?: boolean;
    /**
     * `true` to call the `onClose` function on click outside.
     * @default false
     */
    closeOnClickOutside?: boolean;
    /**
     * The placement of the notification.
     * @default "bottom-start"
     */
    placement?: PLACEMENTS;
    /**
     * Callback fired when the component requests to be closed.
     * @default undefined
     */
    onClose?: () => void;
}
export interface NotificationApiConfigProps extends Omit<NotificationProps, "open" | "autoHide" | "disablePortal" | "closeOnClickOutside" | "onClose" | "position"> {
    key?: string;
    theme?: ThemeProps;
}
export interface NotificationApiComponent extends ForwardRefExoticComponent<NotificationProps & RefAttributes<HTMLDivElement>> {
    show: (config: NotificationApiConfigProps, component?: ReactNode) => void;
    info: (config: NotificationApiConfigProps) => void;
    success: (config: NotificationApiConfigProps) => void;
    warning: (config: NotificationApiConfigProps) => void;
    error: (config: NotificationApiConfigProps) => void;
}
