import type { ReactNode } from "react";
import type { CSSObject } from "styled-components";
export interface PaginationI18n {
    page?: ReactNode;
    of?: ReactNode;
    items?: ReactNode;
}
export interface PaginationProps {
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * Number of data items per page.
     */
    totalItems: number;
    /**
     * Current page number.
     * Used when need to have a controlled state.
     * @default undefined
     */
    page?: number;
    /**
     * Default initial page number.
     * @default undefined
     */
    defaultPage?: number;
    /**
     * Number of items per page.
     * @default 10
     */
    itemsPerPage?: number;
    /**
     * Specify the select number items per page.
     * @default [10, 30, 50, 100],
     */
    pageSize?: number[];
    /**
     * To display the total number and range.
     * @efault true
     */
    showTotal?: boolean;
    /**
     * To display the page size selector.
     * @efault true
     */
    showPageSize?: boolean;
    /**
     * Disable pagination.
     * @default false
     */
    disabled?: boolean;
    /**
     * Called when the page number is changed.
     * @default undefined
     */
    onChange?: (page: number) => void;
    /**
     * Called when change the number items per page.
     * @default undefined
     */
    onChangePageSize?: (pageSize: number) => number;
    /**
     * Custom translations.
     * @default {}
     */
    i18n?: PaginationI18n;
}
