import type { ElementType, HTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, ColorProps, FlexboxProps, LayoutProps, PositionProps, SpaceProps, TypographyProps } from "styled-system";
export interface PaperProps extends Omit<HTMLAttributes<HTMLDivElement>, "color">, SpaceProps, ColorProps, TypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node. Either a string to use a HTML element or a component.
     * @default "div"
     */
    as?: ElementType;
    /**
     * Shadow depth.
     * @default 2
     */
    elevation?: number;
    /**
     * If `true`, rounded corners are disabled.
     * @default false
     */
    square?: boolean;
}
