import type { Modifier } from "@popperjs/core";
import type { ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { ColorProps, PositionProps } from "styled-system";
import type { PortalProps } from "../Portal";
export interface PopperProps extends Omit<PortalProps, "children">, ColorProps, PositionProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * If `true`, the popper tooltip is visible.
     */
    open: boolean;
    /**
     * A HTML element, It's used to set the position of the popper.
     * @default undefined
     */
    anchorEl?: HTMLElement | null;
    /**
     * Always keep the children in the DOM.
     * This prop can be useful in SEO situation or when you want to maximize the
     * responsiveness of the Popper.
     * @default false
     */
    keepMounted?: boolean;
    /**
     * A modifier is a function that is called each time Popper.js needs to compute the position of the popper.
     * For this reason, modifiers should have a very good performance to avoid bottlenecks.
     * To learn how to create a modifier, [read the modifiers documentation](https://popper.js.org/docs/v2/modifiers/).
     * @default []
     */
    modifiers?: Array<Partial<Modifier<any, any>>>;
    /**
     * `true` to show an arrow indicator from where the popper tooltip came.
     * @default true
     */
    arrow?: boolean;
    /**
     * Popper tooltip placement.
     * @default "bottom"
     */
    placement?: "bottom-end" | "bottom-start" | "bottom" | "left-end" | "left-start" | "left" | "right-end" | "right-start" | "right" | "top-end" | "top-start" | "top";
    /**
     * The popper tooltip shadow.`
     * @default 2
     */
    elevation?: number;
}
