import type { ChangeEvent, HTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { FlexboxProps, PositionProps, SpaceProps, TypographyProps } from "styled-system";
export interface RadioGroupProps extends HTMLAttributes<HTMLDivElement>, SpaceProps, TypographyProps, FlexboxProps, PositionProps {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The name used to reference all the radios in the group.
     * If you don't provide this prop, it falls back to a randomly generated name.
     * @default undefined
     */
    name?: string;
    /**
     * Value of the selected radio button.
     * @default undefined
     */
    value?: number | string;
    /**
     * The default value of the selected radio button.
     * @default ""
     */
    defaultValue?: number | string;
    /**
     * The direction to render the input radios.
     * @default "vertical"
     */
    direction?: "horizontal" | "vertical";
    /**
     * If `true`, the radios will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Callback fired when a radio button is selected.
     * @default undefined
     */
    onChange?: (event: ChangeEvent<HTMLInputElement>) => void;
}
