import type { ReactNode } from "react";
import type { SelectNodeProps, SelectOptionProps, SelectProps, SelectValueType } from "../Select.types";
type ItemNode = SelectOptionProps & {
    props?: HTMLElementTagNameMap["optgroup"] | HTMLElementTagNameMap["option"];
};
type CreateSelectMenuItemsProps = Pick<SelectProps, "multiple" | "expandable" | "filterOption" | "noOptionsText" | "itemGroupRenderer" | "itemRenderer" | "noOptionsValue"> & {
    inputValue: string;
    menuSelectedIds: string[];
    items: ItemNode[];
    onSelect: ((ids: string[]) => void) | undefined;
    onDeselect: ((ids: string[]) => void) | undefined;
    parentIsOptGroup: boolean;
};
type IncludeOptionsProps = Pick<SelectProps, "filterOption"> & {
    node: SelectNodeProps;
    inputValue: string;
    menuSelectedIds: string[];
};
type CreateSelectMenuItemsType = {
    options: SelectOptionProps[];
    menuItems: ReactNode[];
    totalOptions: number;
};
/**
 * check if value has content,
 *
 * @param value
 * @returns true if the value has content, false otherwise.
 */
export declare function hasValue(value?: SelectValueType): boolean;
/**
 * Get the menu selected ids from a generated menu items.
 *
 * @param multiple
 * @param value
 * @returns an array of menuItemIds
 */
export declare function getMenuSelectedIds(multiple: boolean, value?: SelectValueType): string[];
/**
 * Get the label associated to a menuItemId.
 *
 * @param menuItemId
 * @param options
 * @returns the label associated to a menuItemId or the menuItemId itself if non is found
 */
export declare function getLabelByMenuItemId(menuItemId: string, options: SelectOptionProps[]): string;
/**
 * Check if the menuItem should be included
 *
 * @param node
 * @param menuSelectedIds
 * @param filterOption
 * @returns
 */
export declare function includeOption({ node, inputValue, menuSelectedIds, filterOption, }: IncludeOptionsProps): boolean;
/**
 * Create the select menu items.
 *
 * @param props the props used to create the select menu items.
 */
export declare function createSelectMenuItems({ items, inputValue, menuSelectedIds, multiple, filterOption, noOptionsText, noOptionsValue, itemGroupRenderer, itemRenderer, onSelect, onDeselect, expandable, parentIsOptGroup, }: CreateSelectMenuItemsProps): CreateSelectMenuItemsType;
export {};
