import type { HTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps } from "styled-system";
export interface SliderProps extends Omit<HTMLAttributes<HTMLDivElement>, "value" | "defaultValue" | "onChange">, SpaceProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The initial value of slider. Add multiple elements to use a range slider.
     * @default undefined
     */
    value?: number[];
    /**
     * The minimum value the slider can slide to.
     * @default 0
     */
    min?: number;
    /**
     * The maximum value the slider can slide to.
     * @default 100
     */
    max?: number;
    /**
     * The granularity the slider can step through values. Must greater than 0.
     * @default 1
     */
    step?: number;
    /**
     * Tick marks on the slider. The key must be number and a number greater or equal than min or less than or equal than max.
     * @default undefined
     */
    marks?: {
        [key: number]: ReactNode;
    };
    /**
     * If `true`, the slider will be vertical.
     * @default false
     */
    vertical?: boolean;
    /**
     * If `true` the tooltip will be always visible or `false` always hidden.
     * @default undefined
     */
    tooltipVisible?: boolean;
    /**
     * Tooltip placement.
     * @default "top"
     */
    tooltipPlacement?: "bottom" | "top";
    /**
     * A function to format the value inside the tooltip.
     * @default undefined
     */
    tooltipFormatter?: (value: number) => ReactNode;
    /**
     * If `true`, the slider will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Callback function that is fired when the user changes the slider's value.
     * @default undefined
     */
    onChange?: (value: number[], event: MouseEvent | TouchEvent) => void;
}
