import type { HTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { BorderProps, LayoutProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface StepProps extends Omit<HTMLAttributes<HTMLDivElement>, "onClick">, SpaceProps, TypographyProps, LayoutProps, BorderProps, ShadowProps {
    /**
     * The index of the steps. The parent will pass this prop.
     * @default 0
     * @ignore
     */
    index?: number;
    /**
     * The Step content.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The variant to use on the step.
     * @default "default"
     */
    variant?: "default" | "error";
    /**
     * The label of the step.
     * @default undefined
     */
    label?: ReactNode;
    /**
     * The description of the step.
     * @default undefined
     */
    description?: ReactNode;
    /**
     * Specify the status of the step.
     *
     * @default false
     */
    completed?: boolean;
    /**
     * The icon to use if the step is waiting or disabled.
     * @default "<StepIcon size={22}>{index + 1}</StepIcon>"
     */
    stepIcon?: ReactNode;
    /**
     * The icon to use if the step is active.
     * @default "<StepIcon size={22}>{index + 1}</StepIcon>"
     */
    stepActiveIcon?: ReactNode;
    /**
     * The icon to use if the step is completed.
     * @default "<CheckCircleOutlinedIcon size={22} />"
     */
    stepCompletedIcon?: ReactNode;
    /**
     * The icon to use if the step status is `error`.
     * @default "<ErrorOutlinedIcon size={22} />"
     */
    stepErrorIcon?: ReactNode;
    /**
     * If `true` the step will be disabled, it can be clicked.
     * @default false
     */
    disabled?: boolean;
    /**
     * Callback called when the selected tab changes.
     * @default undefined
     */
    onClick?: (selectedStep: number, event: SyntheticEvent) => void;
}
