import type { HTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BorderProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface StepperProps extends HTMLAttributes<HTMLDivElement>, SpaceProps, TypographyProps, LayoutProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The Step nodes.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * Set the active step (zero based index).
     * @default 0
     */
    activeStep?: number;
    /**
     * The variant to use.
     * <br />- "default": The normal stepper.
     * <br />- "collapsed": The steps will be collapsed if they are not active.
     * <br />- "responsive": The stepper will enable the collapsed mode automatically on small screens.
     * @default "default"
     */
    variant?: "default" | "collapsed" | "responsive";
    /**
     * The color to use.
     * @default "primary"
     */
    color?: "primary" | "secondary";
    /**
     * The stepper orientation.
     * @default "horizontal"
     */
    orientation?: "horizontal" | "vertical";
    /**
     * Place the label on the bottom of the step icon.
     * @default false
     */
    alternativeLabel?: boolean;
    /**
     * If `true` the steps will be clickable and the flow will be non linear.
     *
     * For example, it will be possible to go from step 1 to 3 without going through step 2.
     *
     * @default false.
     */
    nonLinear?: boolean;
    /**
     * The width from which a stepper is considered to be small and the stepper will render his compact version.
     * @default 425
     */
    smallScreenSize?: number;
    /**
     * Instead of using the icons it will only use dots and the alternative label.
     * @default false
     */
    compact?: boolean;
    /**
     * The icon to use if the step is waiting or disabled.
     * @default undefined
     */
    stepIcon?: ReactNode;
    /**
     * The icon to use if the step is active.
     * @default undefined
     */
    stepActiveIcon?: ReactNode;
    /**
     * The icon to use if the step is completed.
     * @default undefined
     */
    stepCompletedIcon?: ReactNode;
    /**
     * The icon to use if the step status is `error`.
     * @default undefined
     */
    stepErrorIcon?: ReactNode;
}
