import type { ElementType, HTMLAttributes, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { HeightProps, SpaceProps, WidthProps } from "styled-system";
export interface TabProps extends Omit<HTMLAttributes<HTMLButtonElement>, "color">, SpaceProps, WidthProps, HeightProps {
    /**
     * The tab panel content.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     * @default "div"
     */
    as?: ElementType;
    /**
     * The label of the tab.
     * @default undefined
     */
    label?: ReactNode;
    /**
     * An start icon of the tab.
     */
    icon?: ReactNode;
    /**
     * The color of the label.
     * @default undefined
     */
    color?: string;
    /**
     * If `true`, the tab will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the ripple effect will be disabled.
     * @default false
     */
    disableRipple?: boolean;
}
