import type { ElementType, HTMLAttributes, ReactNode, SyntheticEvent } from "react";
import type { CSSObject } from "styled-components";
import type { BorderProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
export interface TabsProps extends Omit<HTMLAttributes<HTMLDivElement>, "onChange">, SpaceProps, TypographyProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The tab list.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     * @default "div"
     */
    as?: ElementType;
    /**
     * The component used for the tabs list node.
     * @default "div"
     */
    tabsListAs?: ElementType;
    /**
     * The index of the selected tab (0-n), `undefined` to not have any tab selected.
     * @default undefined
     */
    selectedTab?: number;
    /**
     * The tabs orientation (layout flow direction).
     * @default "horizontal"
     */
    orientation?: "horizontal" | "vertical";
    /**
     * Determines the color of the `Tab`. it can be an hexadecimal or a css color, it can also be one of the next types:
     * <br/>- primary
     * <br/>- secondary
     * <br/>- success
     * <br/>- warning
     * <br/>- danger
     *
     * @default "primary"
     */
    textColor?: string;
    /**
     * Determines the color of the tab indicator, it can be an hexadecimal or a css color, it can also be one of the next types:
     * <br/>- primary
     * <br/>- secondary
     * <br/>- success
     * <br/>- warning
     * <br/>- danger
     *
     * @default "primary"
     */
    indicatorColor?: string;
    /**
     * If `true`, the tabs will be centered. This property is intended for large views.
     * @default "flex-start"
     */
    align?: "flex-start" | "center" | "flex-end" | "space-around" | "space-between" | "space-evenly";
    /**
     * If `true`, the tabs will take up the full width of its container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * If `true`, all the tabs will be disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Callback called when the selected tab changes.
     * @default undefined
     */
    onChange?: (selectedTab: number, event: SyntheticEvent) => void;
}
