import { Editor } from "@tiptap/core";
import type { Level } from "@tiptap/starter-kit/dist/packages/extension-heading/src";
import { ReactNode } from "react";
import type { BoxProps } from "../Box";
import type { ButtonProps } from "../Button";
import { ButtonGroupProps } from "../ButtonGroup";
import type { PopoverProps } from "../Popover";
export type { Editor } from "@tiptap/core";
export type EditorHandle = {
    editor: Editor | null;
};
export type DefaultUserSuggestion = {
    id: string;
    name: string;
};
export type TipTapEditorProps<UserSuggestion = DefaultUserSuggestion> = Omit<BoxProps, "height" | "onChange"> & {
    renderToolbar?: () => ReactNode;
    height?: string | number;
    content?: string;
    immediatelyRender?: boolean;
    placeholder?: string;
    onChange?: (content: string, mentions: string[]) => void;
    spellCheck?: boolean;
    validateColors?: boolean;
    allowedColors?: string[];
    allowedBackgroundColors?: string[];
    mentionOptions?: {
        displayKey?: keyof UserSuggestion;
        debounceDelayMs?: number;
        debounceIsImmediate?: boolean;
        deleteTriggerWithBackspace?: boolean;
        userSuggestionPromise?: (query: string) => Promise<UserSuggestion[]>;
        userSuggestionRenderer?: (item: UserSuggestion) => ReactNode;
        noResultsRenderer?: string | (() => ReactNode);
        loadingRenderer?: string | (() => ReactNode);
    };
};
export type TipTapEditorAdvancedToolbarProps = {
    children?: ReactNode;
    allowedColors?: string[];
    allowedBackgroundColors?: string[];
    clearText?: string;
    cancelText?: string;
    confirmText?: string;
    className?: string;
};
export type TipTapEditorBasicToolbarProps = {
    children?: ReactNode;
    allowedBackgroundColors?: string[];
    clearText?: string;
    cancelText?: string;
    confirmText?: string;
    className?: string;
};
export type TipTapEditorToolbarProps = BoxProps & {
    children?: ReactNode;
};
export type EditorElement = "bold" | "italic" | "underline" | "strike" | "clear" | "blockquote" | "bulletList" | "orderedList" | "superscript" | "subscript" | "left" | "center" | "right";
export type TipTapEditorBasicControlProps = Omit<ButtonProps, "onClick" | "variant"> & {
    element: EditorElement;
    icon?: ReactNode;
};
export type ColorControlProps = {
    element: "color" | "background";
    colors?: string[];
    buttonProps?: Omit<ButtonProps, "onClick" | "variant">;
    popoverProps?: Omit<PopoverProps, "content">;
};
export type TableControlProps = {
    buttonProps?: Omit<ButtonProps, "onClick" | "variant">;
    popoverProps?: Omit<PopoverProps, "content">;
    icon?: ReactNode;
    insertText?: string;
} & TableToolbarProps;
export type TableToolbarProps = {
    columnText?: string;
    rowText?: string;
    cellText?: string;
    addColumnBeforeText?: string;
    addColumnAfterText?: string;
    deleteColumnText?: string;
    addRowBeforeText?: string;
    addRowAfterText?: string;
    deleteRowText?: string;
    mergeCellsText?: string;
    splitCellText?: string;
    deleteTableText?: string;
};
export type TipTapEditorHeaderControlProps = Omit<ButtonProps, "onClick" | "variant"> & {
    level: Level;
};
export type TipTapEditorLinkControlProps = {
    clearText?: string;
    cancelText?: string;
    confirmText?: string;
    buttonProps?: Omit<ButtonProps, "onClick" | "variant">;
    popoverProps?: Omit<PopoverProps, "content">;
    placeholder?: string;
};
export type TipTapEditorControlGroupProps = ButtonGroupProps & {
    children: ReactNode;
};
