import type { ReactNode, RefAttributes, RefObject, SyntheticEvent } from "react";
import type { PaperProps } from "../Paper";
import type { PopperProps } from "../Popper";
export type TooltipTriggers = "click" | "hover" | "contextMenu";
export interface TooltipProps extends Omit<PopperProps, "open">, Omit<PaperProps, "onClick" | "onMouseEnter" | "onMouseLeave" | "onContextMenu" | "onClickOutside" | "content"> {
    /**
     * The content of the component.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The ref that will have the api method exposed.
     */
    tooltipRef?: RefObject<TooltipHTMLElement>;
    /**
     * The open state to override the tooltip one.
     * @default undefined
     */
    open?: boolean;
    /**
     * If the tooltip is open by default.
     * @default false
     */
    defaultOpen?: boolean;
    /**
     * `true` to close the popover on click outside.
     * @default true
     */
    closeOnClickOutside?: boolean;
    /**
     * Tooltip trigger mode.
     * Keep in mind that `hover` can't be used in touchscreens.
     * @default ["click", "hover"]
     */
    trigger?: TooltipTriggers | TooltipTriggers[];
    /**
     * The content of the tooltip.
     */
    content: ReactNode | string;
    /**
     * Callback fired when open the tooltip.
     * @default undefined
     */
    onOpen?: (event: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Callback fired when close the tooltip.
     * @default undefined
     */
    onClose?: (event: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Callback fired when trigger a onClick on the anchor element.
     * @default undefined
     */
    onClick?: (open: boolean, event: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Callback fired when trigger mouseEnter, only when trigger contains hover.
     * @default undefined
     */
    onMouseEnter?: (open: boolean, event: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Callback fired when trigger mouseLeave, only when trigger contains hover.
     * @default undefined
     */
    onMouseLeave?: (open: boolean, event: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Callback fired when trigger right click, only when trigger contains `contextMenu`.
     * @default undefined
     */
    onContextMenu?: (open: boolean, event: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Callback fired when click outside the popover. Useful if you want to control the state.
     * @default undefined
     */
    onClickOutside?: (open: boolean, event: MouseEvent | TouchEvent | SyntheticEvent) => void;
}
export interface TooltipHTMLElement extends RefAttributes<HTMLDivElement> {
    /**
     * Trigger tooltip open function.
     */
    open: (event?: MouseEvent | TouchEvent | SyntheticEvent) => void;
    /**
     * Trigger tooltip close function.
     */
    close: (event?: MouseEvent | TouchEvent | SyntheticEvent) => void;
}
