import type { TypographyProps as EdsTypographyProps } from "@equinor/eds-core-react";
import type { ElementType, ReactNode } from "react";
import type { CSSObject } from "styled-components";
import type { BackgroundProps, BorderProps, ColorProps, FlexboxProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps as SsTypographyProps } from "styled-system";
export interface TypographyProps extends Omit<EdsTypographyProps, "variant" | "color">, SpaceProps, Omit<ColorProps, "color">, SsTypographyProps, LayoutProps, FlexboxProps, BackgroundProps, BorderProps, PositionProps, ShadowProps {
    /**
     * The tab list.
     */
    children?: ReactNode;
    /**
     * The className of the component.
     */
    className?: string;
    /**
     * The css object ot override the styles.
     */
    css?: CSSObject;
    /**
     * The component used for the root node.
     * @default "<p>"
     */
    as?: ElementType;
    /**
     * The variant to use.
     * @default "p"
     */
    variant?: "h1" | "h1_bold" | "h2" | "h3" | "h4" | "h5" | "h6" | "p" | "overline" | "ingress" | "body_long" | "body_long_link" | "body_long_italic" | "body_long_bold" | "body_long_bold_italic" | "body_short" | "body_short_link" | "body_short_italic" | "body_short_bold" | "body_short_bold_italic";
    /**
     * The color to be used, it can be an hexadecimal or a css color, it can also be one of the next types:
     * <br/>- primary
     * <br/>- secondary
     * <br/>- success
     * <br/>- warning
     * <br/>- danger
     * <br/>- disabled
     *
     * @default undefined
     */
    color?: "primary" | "secondary" | "success" | "warning" | "danger" | "disabled" | string;
    /**
     * Css `text-transform` property.
     * @default undefined
     */
    textTransform?: string;
    /**
     * CSS `word-wrap` property.
     * @default undefined
     */
    wordWrap?: string;
}
