import type { BackgroundProps, BorderProps, ColorProps, FlexboxProps, GridProps, LayoutProps, PositionProps, ShadowProps, SpaceProps, TypographyProps } from "styled-system";
/**
 * Extract the space props.
 * https://styled-system.com/api/#space
 *
 * @param {object} props the props to extract the space attributes.
 */
export declare const getStyledSystemSpaceProps: (props: SpaceProps) => any;
/**
 * Extract the space props and return the other props;
 * https://styled-system.com/api/#space
 *
 * @param {object} props the props to extract the space attributes.
 */
export declare const removeStyledSystemSpaceProps: (props: SpaceProps) => {};
/**
 * Extract the color props.
 * https://styled-system.com/api/#color
 *
 * @param {object} props the props to extract the color attributes.
 */
export declare const getStyledSystemColorProps: (props: ColorProps) => any;
/**
 * Extract the color props and return the others.
 * https://styled-system.com/api/#color
 *
 * @param {object} props the props to extract the color attributes.
 */
export declare const removeStyledSystemColorProps: (props: ColorProps) => {
    opacity?: import("styled-system").ResponsiveValue<import("csstype").Property.Opacity, Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> | undefined;
};
/**
 * Extract the typography props.
 * https://styled-system.com/api/#typography
 *
 * @param {object} props the props to extract the typography attributes.
 */
export declare const getStyledSystemTypographyProps: (props: TypographyProps) => any;
/**
 * Extract the typography props and return the others.
 * https://styled-system.com/api/#typography
 *
 * @param {object} props the props to extract the typography attributes.
 */
export declare const removeStyledSystemTypographyProps: (props: TypographyProps) => {};
/**
 * Extract the layout props.
 * https://styled-system.com/api/#layout
 *
 * @param {object} props the props to extract the layout attributes.
 */
export declare const getStyledSystemLayoutProps: (props: LayoutProps) => any;
/**
 * Extract the layout props and return the others.
 * https://styled-system.com/api/#layout
 *
 * @param {object} props the props to extract the layout attributes.
 */
export declare const removeStyledSystemLayoutProps: (props: LayoutProps) => {};
/**
 * Extract the flexbox props.
 * https://styled-system.com/api/#flexbox
 *
 * @param {object} props the props to extract the flexbox attributes.
 */
export declare const getStyledSystemFlexboxProps: (props: FlexboxProps) => any;
/**
 * Extract the flexbox props and return the others.
 * https://styled-system.com/api/#flexbox
 *
 * @param {object} props the props to extract the flexbox attributes.
 */
export declare const removeStyledSystemFlexboxProps: (props: FlexboxProps) => {};
/**
 * Extract the grid layout props.
 * https://styled-system.com/api/#grid-layout
 *
 * @param {object} props the props to extract the grid layout attributes.
 */
export declare const getStyledSystemGridLayoutProps: (props: GridProps) => any;
/**
 * Extract the grid layout props and return the others.
 * https://styled-system.com/api/#grid-layout
 *
 * @param {object} props the props to extract the grid layout attributes.
 */
export declare const removeStyledSystemGridLayoutProps: (props: GridProps) => {
    gridGap?: import("styled-system").ResponsiveValue<import("csstype").Property.GridGap<import("styled-system").TLengthStyledSystem>, Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> | undefined;
    gridColumnGap?: import("styled-system").ResponsiveValue<import("csstype").Property.GridColumnGap<import("styled-system").TLengthStyledSystem>, Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> | undefined;
    gridRowGap?: import("styled-system").ResponsiveValue<import("csstype").Property.GridRowGap<import("styled-system").TLengthStyledSystem>, Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> | undefined;
};
/**
 * Extract the background props.
 * https://styled-system.com/api/#background
 *
 * @param {object} props the props to extract the background attributes.
 */
export declare const getStyledSystemBackgroundProps: (props: BackgroundProps) => any;
/**
 * Extract the background props and return the others
 * https://styled-system.com/api/#background
 *
 * @param {object} props the props to extract the background attributes.
 */
export declare const removeStyledSystemBackgroundProps: (props: BackgroundProps) => {
    background?: import("styled-system").ResponsiveValue<import("csstype").Property.Background<import("styled-system").TLengthStyledSystem>, Required<import("styled-system").Theme<import("styled-system").TLengthStyledSystem>>> | undefined;
};
/**
 * Extract the border props.
 * https://styled-system.com/api/#border
 *
 * @param {object} props the props to extract the border attributes.
 */
export declare const getStyledSystemBorderProps: (props: BorderProps) => any;
/**
 * Extract the border props and return the others.
 * https://styled-system.com/api/#border
 *
 * @param {object} props the props to extract the border attributes.
 */
export declare const removeStyledSystemBorderProps: (props: BorderProps) => {};
/**
 * Extract the position props.
 * https://styled-system.com/api/#position
 *
 * @param {object} props the props to extract the position attributes.
 */
export declare const getStyledSystemPositionProps: (props: PositionProps) => any;
/**
 * Extract the position props and return the others.
 * https://styled-system.com/api/#position
 *
 * @param {object} props the props to extract the position attributes.
 */
export declare const removeStyledSystemPositionProps: (props: PositionProps) => {};
/**
 * Extract the shadow props.
 * https://styled-system.com/api/#shadow
 *
 * @param {object} props the props to extract the shadow attributes.
 */
export declare const getStyledSystemShadowProps: (props: ShadowProps) => any;
/**
 * Extract the shadow props and return the others.
 * https://styled-system.com/api/#shadow
 *
 * @param {object} props the props to extract the shadow attributes.
 */
export declare const removeStyledSystemShadowProps: (props: ShadowProps) => {};
