interface Size {
    width: number;
    height: number;
}
/**
 * This hook helps you to dynamically recover the width and the height of an HTML element.
 * Dimensions are updated on load, on mount/un-mount, when resizing the window and when the ref changes.
 *
 * @example
 * function Component() {
 *    const [elementRef, { width, height }] = useElementSize()
 *    ...
 *    return (
 *      <div ref={elementRef}>...</div>
 *    );
 * }
 */
export default function useElementSize<T extends HTMLElement = HTMLDivElement>(): [(node: T | null) => void, Size];
export {};
