/**
 * Generate a react useCallback that uses a ref as a deps. This hook is useful to ONLY generate a
 * function once.
 *
 * @param callback the callback to call.
 * @returns a useCallback function that is only generated once.
 *
 * @example
 * function App() {
 *    const setValue = useEventCallback(() => {
 *      ...
 *    }
 * }
 */
export default function useEventCallback<Args extends unknown[], R>(callback: (...args: Args) => R): (...args: Args) => R;
