import type { Dispatch, SetStateAction } from "react";
type SetValue<T> = Dispatch<SetStateAction<T>>;
declare global {
    interface WindowEventMap {
        "local-storage": CustomEvent;
    }
}
/**
 * Persist the state with local storage so that it remains after a page refresh.
 * This hook is used in the same way as useState except that you must pass the storage key in the 1st parameter.
 * If the window object is not present (as in SSR), useLocalStorage() will return the initial value.
 *
 * @param key the local storage key.
 * @param initialValue the initial value.
 * @returns [value, setValue]
 *
 * @example
 * function App() {
 *      const [isDarkTheme, setDarkTheme] = useLocalStorage('darkTheme', true);
 *      ...
 * }
 */
export default function useLocalStorage<T>(key: string, initialValue: T): [T, SetValue<T>];
export {};
