/**
 * Easily retrieve media dimensions with this Hook which also works onResize.
 *
 * ! Before Safari 14, `MediaQueryList` is based on `EventTarget` and only supports `addListener`/`removeListener` for media queries.
 *
 * @param query the media query to check.
 * @returns true if the window matches the media query, false otherwise.
 *
 * @example
 * function App() {
 *      const matches = useMediaQuery('(min-width: 768px)')
 *      return (
 *          <div>
 *              {`The view port is ${matches ? 'at least' : 'less than'} 768 pixels wide`}
 *          </div>
 *      )
 * }
 */
export default function useMediaQuery(query: string): boolean;
