type Value<T> = T | null;
/**
 * This React Hook allows you to read a value from localStorage by its key.
 * It can be useful if you just want to read without passing a default value.
 *
 * If the window object is not present (as in SSR), or if the value doesn't exist, `useReadLocalStorage()` will return null.
 *
 * @param key the local storage key.
 * @returns the value stored or null if not present.
 *
 * @example
 * function App() {
 *      const darkMode = useReadLocalStorage('darkMode');
 *      return <p>DarkMode is {darkMode ? 'enabled' : 'disabled'}</p>
 * }
 */
export default function useReadLocalStorage<T>(key: string): Value<T>;
export {};
