import type { Dispatch, SetStateAction } from "react";
/**
 * Custom hook to include a callback function for useState which was previously available for setState in class components.
 * It will render and then call the callback.
 *
 * @param initialState the initial state.
 * @param callback the callback to execute after setting the state.
 *
 * @example
 * function Component() {
 *    const [count, setCount] = useStateWithCallback<number>(0, count => {
 *      if (count > 1) {
 *        console.log('Threshold of over 1 reached.');
 *      } else {
 *        console.log('No threshold reached.');
 *      }
 *    });
 *    ...
 * }
 */
export default function useStateWithCallback<T>(initialState: T, callback: (state: T) => void): [T, Dispatch<SetStateAction<T>>];
