/**
 * Custom hook to include a callback function for useState which was previously available for setState in class components.
 *
 * @param initialValue the initial value.
 *
 * @example
 * function Component() {
 *    const [count, setCount] = useStateWithCallbackLazy(0);
 *    ...
 *    const handleClick = () => {
 *      setCount(count + 1, (currentCount) => {
 *          if (currentCount > 1) {
 *              console.log('Threshold of over 1 reached.');
 *          } else {
 *              console.log('No threshold reached.');
 *          }
 *      });
 *    };
 *    ...
 * }
 */
export default function useStateWithCallbackLazy<T>(initialValue: T): [T, (newValue: T, callback?: (...args: any[]) => void) => void];
